@@ -4,7 +4,7 @@ from .augment import *
 from .learner import *
 from .mixup import *
 from ..basics import *
-from ..callback import channelslast, ema, lr_finder, casttotensor, tracker
+from ..callback import channelslast, ema, lr_finder, tracker
 from ..data.all import *
 from ..losses import *
 from ..metrics import *
